package testcase1;


import java.net.URL;
import java.util.HashMap;
import java.util.Map;
import javax.ejb.embeddable.EJBContainer;
import javax.naming.Context;
import javax.naming.NamingException;

import org.testng.Assert;
import org.testng.annotations.AfterSuite;
import org.testng.annotations.BeforeSuite;
import org.testng.annotations.Test;


/**
 * Test embedded container functionality.
 *
 * @author pross
 */
public class TestEmbeddedContainer {

    private EJBContainer ejbContainer;


    @BeforeSuite
    public void startupContainer() {
        URL url  = Thread.currentThread().getContextClassLoader().getResource("test-domain.xml");
        String configFileName = url.getFile();
        Map<String, Object> ejbContainerProperties = new HashMap<String, Object>();
        ejbContainerProperties.put("org.glassfish.ejb.embedded.glassfish.configuration.file", configFileName);
        long containerStartBeginTime = System.currentTimeMillis();
        ejbContainer = EJBContainer.createEJBContainer(ejbContainerProperties);
        long containerStartEndTime = System.currentTimeMillis();
        System.out.println("Embedded container started in " + (containerStartEndTime - containerStartBeginTime) + " ms.");
    }


    @AfterSuite
    public void shutdownContainer() {
        if (ejbContainer != null) {
            ejbContainer.close();
        }
    }


    @Test(groups = {"container-init"})
    public void testEmbeddedContainer() throws Exception {
        System.out.println("Testing embedded container.");
        Assert.assertNotNull(ejbContainer);
        Assert.assertNotNull(ejbContainer.getContext());
        Assert.assertNotNull(ejbContainer.getContext().lookup("java:comp/UserTransaction"));
    }


    public static void main(String[] args) {
        try {
           System.out.println("Test main method invoked.");
           TestEmbeddedContainer testEmbeddedContainer = new TestEmbeddedContainer();
           testEmbeddedContainer.startupContainer();
           testEmbeddedContainer.testEmbeddedContainer();
           testEmbeddedContainer.shutdownContainer();
        } catch (Exception e) {
            e.printStackTrace(System.err);
        }
    }


}
